var react = require('react');

(function (ScreenSize) {
  ScreenSize["xs"] = "xs";
  ScreenSize["s"] = "s";
  ScreenSize["m"] = "m";
  ScreenSize["l"] = "l";
  ScreenSize["xl"] = "xl";
})(exports.ScreenSize || (exports.ScreenSize = {}));

var useScreenSize = function useScreenSize() {
  var isClient = typeof window === 'object';
  var getSize = react.useCallback(function () {
    return {
      width: isClient ? window.innerWidth : 0,
      height: isClient ? window.innerHeight : 0,
      screen: exports.ScreenSize.s
    };
  }, [isClient]);

  var _useState = react.useState(getSize),
      windowSize = _useState[0],
      setWindowSize = _useState[1];

  react.useEffect(function () {
    if (!isClient) {
      return;
    }

    function handleResize() {
      setWindowSize(getSize());
    }

    window.addEventListener('resize', handleResize);
    return function () {
      return window.removeEventListener('resize', handleResize);
    };
  }, [isClient, getSize]);

  if (windowSize.width < 576) {
    windowSize.screen = exports.ScreenSize.xs;
  } else if (windowSize.width >= 576 && windowSize.width < 768) {
    windowSize.screen = exports.ScreenSize.s;
  } else if (windowSize.width >= 768 && windowSize.width < 992) {
    windowSize.screen = exports.ScreenSize.m;
  } else if (windowSize.width >= 992 && windowSize.width < 1200) {
    windowSize.screen = exports.ScreenSize.l;
  } else {
    windowSize.screen = exports.ScreenSize.xl;
  }

  return windowSize;
};

exports.default = useScreenSize;
//# sourceMappingURL=index.js.map
