import { useCallback, useState, useEffect } from 'react';

var ScreenSize;

(function (ScreenSize) {
  ScreenSize["xs"] = "xs";
  ScreenSize["s"] = "s";
  ScreenSize["m"] = "m";
  ScreenSize["l"] = "l";
  ScreenSize["xl"] = "xl";
})(ScreenSize || (ScreenSize = {}));

var useScreenSize = function useScreenSize() {
  var isClient = typeof window === 'object';
  var getSize = useCallback(function () {
    return {
      width: isClient ? window.innerWidth : 0,
      height: isClient ? window.innerHeight : 0,
      screen: ScreenSize.s
    };
  }, [isClient]);

  var _useState = useState(getSize),
      windowSize = _useState[0],
      setWindowSize = _useState[1];

  useEffect(function () {
    if (!isClient) {
      return;
    }

    function handleResize() {
      setWindowSize(getSize());
    }

    window.addEventListener('resize', handleResize);
    return function () {
      return window.removeEventListener('resize', handleResize);
    };
  }, [isClient, getSize]);

  if (windowSize.width < 576) {
    windowSize.screen = ScreenSize.xs;
  } else if (windowSize.width >= 576 && windowSize.width < 768) {
    windowSize.screen = ScreenSize.s;
  } else if (windowSize.width >= 768 && windowSize.width < 992) {
    windowSize.screen = ScreenSize.m;
  } else if (windowSize.width >= 992 && windowSize.width < 1200) {
    windowSize.screen = ScreenSize.l;
  } else {
    windowSize.screen = ScreenSize.xl;
  }

  return windowSize;
};

export default useScreenSize;
export { ScreenSize };
//# sourceMappingURL=index.modern.js.map
